==> vala-0.1.0.tar.bz2: vala-0.1.0/ccode/valaccodeunaryexpression.c <==
/* valaccodeunaryexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valaccodeunaryexpression.h"
#include <stdlib.h>
#include <string.h>
#include <ccode/valaccodenode.h>

struct _ValaCCodeUnaryExpressionPrivate {
	ValaCCodeUnaryOperator _operator;
	ValaCCodeExpression* _inner;
};
#define VALA_CCODE_UNARY_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_UNARY_EXPRESSION, ValaCCodeUnaryExpressionPrivate))
enum  {
	VALA_CCODE_UNARY_EXPRESSION_DUMMY_PROPERTY,
	VALA_CCODE_UNARY_EXPRESSION_OPERATOR,
	VALA_CCODE_UNARY_EXPRESSION_INNER
};
static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_unary_expression_parent_class = NULL;
static void vala_ccode_unary_expression_dispose (GObject * obj);


ValaCCodeUnaryExpression* vala_ccode_unary_expression_new (ValaCCodeUnaryOperator op, ValaCCodeExpression* expr)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeUnaryExpression * self;
	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
	__params = g_new0 (GParameter, 2);
	__params_it = __params;
	(__params_it->name = "operator", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, op), __params_it++);
	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_UNARY_EXPRESSION, __params_it - __params, __params);
	return self;
}


static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeUnaryExpression * self;
	self = VALA_CCODE_UNARY_EXPRESSION (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PLUS) {
		vala_ccode_writer_write_string (writer, "+");
	} else {
		if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_MINUS) {
			vala_ccode_writer_write_string (writer, "-");
		} else {
			if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_LOGICAL_NEGATION) {
				vala_ccode_writer_write_string (writer, "!");
			} else {
				if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_BITWISE_COMPLEMENT) {
					vala_ccode_writer_write_string (writer, "~");
				} else {
					if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION) {
						vala_ccode_writer_write_string (writer, "*");
					} else {
						if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF) {
							vala_ccode_writer_write_string (writer, "&");
						} else {
							if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PREFIX_INCREMENT) {
								vala_ccode_writer_write_string (writer, "++");
							} else {
								if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PREFIX_DECREMENT) {
									vala_ccode_writer_write_string (writer, "--");
								}
							}
						}
					}
				}
			}
		}
	}
	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_unary_expression_get_inner (self)), writer);
	if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_POSTFIX_INCREMENT) {
		vala_ccode_writer_write_string (writer, "++");
	} else {
		if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_POSTFIX_DECREMENT) {
			vala_ccode_writer_write_string (writer, "--");
		}
	}
}


ValaCCodeUnaryOperator vala_ccode_unary_expression_get_operator (ValaCCodeUnaryExpression* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self), 0);
	return self->priv->_operator;
}


void vala_ccode_unary_expression_set_operator (ValaCCodeUnaryExpression* self, ValaCCodeUnaryOperator value)
{
	g_return_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self));
	self->priv->_operator = value;
}


ValaCCodeExpression* vala_ccode_unary_expression_get_inner (ValaCCodeUnaryExpression* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self), NULL);
	return self->priv->_inner;
}


void vala_ccode_unary_expression_set_inner (ValaCCodeUnaryExpression* self, ValaCCodeExpression* value)
{
	ValaCCodeExpression* __temp2;
	g_return_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self));
	__temp2 = NULL;
	self->priv->_inner = (__temp2 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp2);
}


static void vala_ccode_unary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeUnaryExpression * self;
	self = VALA_CCODE_UNARY_EXPRESSION (object);
	switch (property_id) {
		case VALA_CCODE_UNARY_EXPRESSION_OPERATOR:
		g_value_set_int (value, vala_ccode_unary_expression_get_operator (self));
		break;
		case VALA_CCODE_UNARY_EXPRESSION_INNER:
		g_value_set_object (value, vala_ccode_unary_expression_get_inner (self));
		break;
	}
}


static void vala_ccode_unary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeUnaryExpression * self;
	self = VALA_CCODE_UNARY_EXPRESSION (object);
	switch (property_id) {
		case VALA_CCODE_UNARY_EXPRESSION_OPERATOR:
		vala_ccode_unary_expression_set_operator (self, g_value_get_int (value));
		break;
		case VALA_CCODE_UNARY_EXPRESSION_INNER:
		vala_ccode_unary_expression_set_inner (self, g_value_get_object (value));
		break;
	}
}


static void vala_ccode_unary_expression_class_init (ValaCCodeUnaryExpressionClass * klass)
{
	vala_ccode_unary_expression_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeUnaryExpressionPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_unary_expression_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_unary_expression_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_unary_expression_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_unary_expression_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_unary_expression_init (ValaCCodeUnaryExpression * self)
{
	self->priv = VALA_CCODE_UNARY_EXPRESSION_GET_PRIVATE (self);
}


static void vala_ccode_unary_expression_dispose (GObject * obj)
{
	ValaCCodeUnaryExpression * self;
	ValaCCodeUnaryExpressionClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_UNARY_EXPRESSION (obj);
	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
	klass = VALA_CCODE_UNARY_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_UNARY_EXPRESSION));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_unary_expression_get_type ()
{
	static GType vala_ccode_unary_expression_type_id = 0;
	if (G_UNLIKELY (vala_ccode_unary_expression_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeUnaryExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_unary_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeUnaryExpression), 0, (GInstanceInitFunc) vala_ccode_unary_expression_init };
		vala_ccode_unary_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeUnaryExpression", &g_define_type_info, 0);
	}
	return vala_ccode_unary_expression_type_id;
}

==> vala-0.1.2.tar.bz2: vala-0.1.2/ccode/valaccodeunaryexpression.c <==
/* valaccodeunaryexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaccodeunaryexpression.h"
#include <stdlib.h>
#include <string.h>
#include <ccode/valaccodenode.h>

struct _ValaCCodeUnaryExpressionPrivate {
	ValaCCodeUnaryOperator _operator;
	ValaCCodeExpression* _inner;
};
#define VALA_CCODE_UNARY_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_UNARY_EXPRESSION, ValaCCodeUnaryExpressionPrivate))
enum  {
	VALA_CCODE_UNARY_EXPRESSION_DUMMY_PROPERTY,
	VALA_CCODE_UNARY_EXPRESSION_OPERATOR,
	VALA_CCODE_UNARY_EXPRESSION_INNER
};
static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_unary_expression_parent_class = NULL;
static void vala_ccode_unary_expression_dispose (GObject * obj);


ValaCCodeUnaryExpression* vala_ccode_unary_expression_new (ValaCCodeUnaryOperator op, ValaCCodeExpression* expr)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeUnaryExpression * self;
	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_UNARY_EXPRESSION, __params_it - __params, __params);
	vala_ccode_unary_expression_set_operator (self, op);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_ccode_unary_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeUnaryExpression * self;
	self = ((ValaCCodeUnaryExpression*) base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PLUS) {
		vala_ccode_writer_write_string (writer, "+");
	} else {
		if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_MINUS) {
			vala_ccode_writer_write_string (writer, "-");
		} else {
			if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_LOGICAL_NEGATION) {
				vala_ccode_writer_write_string (writer, "!");
			} else {
				if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_BITWISE_COMPLEMENT) {
					vala_ccode_writer_write_string (writer, "~");
				} else {
					if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_POINTER_INDIRECTION) {
						vala_ccode_writer_write_string (writer, "*");
					} else {
						if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF) {
							vala_ccode_writer_write_string (writer, "&");
						} else {
							if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PREFIX_INCREMENT) {
								vala_ccode_writer_write_string (writer, "++");
							} else {
								if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_PREFIX_DECREMENT) {
									vala_ccode_writer_write_string (writer, "--");
								}
							}
						}
					}
				}
			}
		}
	}
	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_unary_expression_get_inner (self)), writer);
	if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_POSTFIX_INCREMENT) {
		vala_ccode_writer_write_string (writer, "++");
	} else {
		if (vala_ccode_unary_expression_get_operator (self) == VALA_CCODE_UNARY_OPERATOR_POSTFIX_DECREMENT) {
			vala_ccode_writer_write_string (writer, "--");
		}
	}
}


ValaCCodeUnaryOperator vala_ccode_unary_expression_get_operator (ValaCCodeUnaryExpression* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self), 0);
	return self->priv->_operator;
}


void vala_ccode_unary_expression_set_operator (ValaCCodeUnaryExpression* self, ValaCCodeUnaryOperator value)
{
	g_return_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self));
	self->priv->_operator = value;
}


ValaCCodeExpression* vala_ccode_unary_expression_get_inner (ValaCCodeUnaryExpression* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self), NULL);
	return self->priv->_inner;
}


void vala_ccode_unary_expression_set_inner (ValaCCodeUnaryExpression* self, ValaCCodeExpression* value)
{
	ValaCCodeExpression* __temp2;
	g_return_if_fail (VALA_IS_CCODE_UNARY_EXPRESSION (self));
	__temp2 = NULL;
	self->priv->_inner = (__temp2 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp2);
}


static void vala_ccode_unary_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeUnaryExpression * self;
	self = VALA_CCODE_UNARY_EXPRESSION (object);
	switch (property_id) {
		case VALA_CCODE_UNARY_EXPRESSION_OPERATOR:
		g_value_set_int (value, vala_ccode_unary_expression_get_operator (self));
		break;
		case VALA_CCODE_UNARY_EXPRESSION_INNER:
		g_value_set_object (value, vala_ccode_unary_expression_get_inner (self));
		break;
	}
}


static void vala_ccode_unary_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeUnaryExpression * self;
	self = VALA_CCODE_UNARY_EXPRESSION (object);
	switch (property_id) {
		case VALA_CCODE_UNARY_EXPRESSION_OPERATOR:
		vala_ccode_unary_expression_set_operator (self, g_value_get_int (value));
		break;
		case VALA_CCODE_UNARY_EXPRESSION_INNER:
		vala_ccode_unary_expression_set_inner (self, g_value_get_object (value));
		break;
	}
}


static void vala_ccode_unary_expression_class_init (ValaCCodeUnaryExpressionClass * klass)
{
	vala_ccode_unary_expression_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeUnaryExpressionPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_unary_expression_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_unary_expression_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_unary_expression_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_unary_expression_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_UNARY_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_unary_expression_init (ValaCCodeUnaryExpression * self)
{
	self->priv = VALA_CCODE_UNARY_EXPRESSION_GET_PRIVATE (self);
}


static void vala_ccode_unary_expression_dispose (GObject * obj)
{
	ValaCCodeUnaryExpression * self;
	ValaCCodeUnaryExpressionClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_UNARY_EXPRESSION (obj);
	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
	klass = VALA_CCODE_UNARY_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_UNARY_EXPRESSION));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_unary_expression_get_type (void)
{
	static GType vala_ccode_unary_expression_type_id = 0;
	if (G_UNLIKELY (vala_ccode_unary_expression_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeUnaryExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_unary_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeUnaryExpression), 0, (GInstanceInitFunc) vala_ccode_unary_expression_init };
		vala_ccode_unary_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeUnaryExpression", &g_define_type_info, 0);
	}
	return vala_ccode_unary_expression_type_id;
}
